# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/provider/package/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/provider/package/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Provider\\Package\\": "packages/provider/package/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Provider\Package\Providers\PackageServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Package'  => Provider\Package\Facades\Package::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Provider\\PackageTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Provider\Package\Providers\PackageServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Provider\Package\Providers\PackageServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Provider\Package\Providers\PackageServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/package/{modulename}

**User**

    http://path-to-route-folder/user/package/{modulename}

**Public**

    http://path-to-route-folder/packages


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/package/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/package/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/package/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/package/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/package/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/package/{modulename}/{slug}
    METHOD: GET